package com.huimv.production.datasource.controller;

import com.alibaba.fastjson.JSONObject;
import com.huimv.common.result.Result;
import com.huimv.common.result.ResultCode;
import com.huimv.production.datasource.service.IErpDataService;
import com.huimv.production.datasource.utils.TokenUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.repository.query.Param;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.io.IOException;
import java.util.Date;

/**
 * @Project :
 * @Package : com.huimv.production.datasource.controller
 * @Description : TODO
 * @Version : 1.0
 * @Author : ZhuoNing
 * @Create : 2020-12-25
 **/
@RestController
@Slf4j
@RequestMapping(value = "/erpData",method=RequestMethod.GET)
public class ErpDataController {

    @Autowired
    private IErpDataService erpDataService;
    @Autowired
    private TokenUtil tokenUtil;
    /**
     * @Method      : getPsy
     * @Description : 获取Psy
     * @Params      : []
     * @Return      : java.lang.String
     * 
     * @Author      : ZhuoNing
     * @Date        : 2021/5/14       
     * @Time        : 20:57
     */
    @RequestMapping("/getPsy")
    public Result getPsy(@Param(value="farmID") String farmID,@Param(value="startDate") String startDate,@Param(value="endDate") String endDate,@RequestParam(value = "accessToken",required = true) String accessToken){
        System.out.println("farmID="+farmID);
        System.out.println("startDate="+startDate);
        System.out.println("endDate="+endDate);
        System.out.println("accessToken="+accessToken);
        // 验证token
        Result result = tokenUtil.verifyToken(accessToken);
        if(!result.isSuccess()){
            return result;
        }
        return new Result(ResultCode.SUCCESS,erpDataService.getPsy(farmID,startDate,endDate));
    }

    /**
     * @Method      : getReEstrusRate
     * @Description : 获取返情率
     * @Params      : []
     * @Return      : java.lang.String
     * 
     * @Author      : ZhuoNing
     * @Date        : 2021/5/14       
     * @Time        : 21:14
     */
    @RequestMapping("/getReEstrusRate")
    public Result getReEstrusRate(@Param(value="startDate") String startDate,@Param(value="endDate") String endDate,@RequestParam(value = "accessToken",required = true) String accessToken,@RequestParam(value = "farmName",required = true) String farmName){
        // 验证token
        Result result = tokenUtil.verifyToken(accessToken);
        if(!result.isSuccess()){
            return result;
        }
        return new Result(ResultCode.SUCCESS,erpDataService.getReEstrusRate(startDate,endDate,farmName));
    }

    /**
     * @Method      : getParturitionRate
     * @Description : 获取分娩率
     * @Params      : []
     * @Return      : java.lang.String
     * 
     * @Author      : ZhuoNing
     * @Date        : 2021/5/15       
     * @Time        : 11:02
     */
    @RequestMapping("/getParturitionRate")
    public Result getParturitionRate(@Param(value="startDate") String startDate,@Param(value="endDate") String endDate,@RequestParam(value = "accessToken",required = true) String accessToken,@RequestParam(value = "farmName",required = true) String farmName){
        // 验证token
        Result result = tokenUtil.verifyToken(accessToken);
        if(!result.isSuccess()){
            return result;
        }
        return new Result(ResultCode.SUCCESS,erpDataService.getParturitionRate(startDate,endDate,farmName));
    }

    /**
     * @Method      : getStorage
     * @Description : 获取各品种及各自存栏
     * @Params      : []
     * @Return      : java.lang.String
     * 
     * @Author      : ZhuoNing
     * @Date        : 2021/5/15       
     * @Time        : 11:16
     */
    @RequestMapping("/getStorage")
    public Result getStorage(@RequestParam(value = "accessToken",required = true) String accessToken,@RequestParam(value = "farmName",required = true) String farmName){
        // 验证token
        Result result = tokenUtil.verifyToken(accessToken);
        if(!result.isSuccess()){
            return result;
        }
        return new Result(ResultCode.SUCCESS,erpDataService.getStorage(farmName));
    }

    /**+
     * @Method      : getPigletInfo
     * @Description : 获取均产仔数
     * @Params      : []
     * @Return      : java.lang.String
     * 
     * @Author      : ZhuoNing
     * @Date        : 2021/5/15       
     * @Time        : 11:18
     */
    @RequestMapping("/getPigletInfo")
    public Result getPigletInfo(@Param(value="startDate") String startDate,@Param(value="endDate") String endDate,@RequestParam(value = "accessToken",required = true) String accessToken,@RequestParam(value = "farmName",required = true) String farmName){
        // 验证token
        Result result = tokenUtil.verifyToken(accessToken);
        if(!result.isSuccess()){
            return result;
        }
        return new Result(ResultCode.SUCCESS,erpDataService.getPigletInfo(startDate,endDate,farmName));
    }

    /**
     * @Method      : getMatingTimes
     * @Description : 配种数量
     * @Params      : []
     * @Return      : java.lang.String
     * 
     * @Author      : ZhuoNing
     * @Date        : 2021/5/15       
     * @Time        : 11:35
     */
    @RequestMapping("/getMateQuantity")
    public Result getMateQuantity(@Param(value="startDate") String startDate,@Param(value="endDate") String endDate,@RequestParam(value = "accessToken",required = true) String accessToken,@RequestParam(value = "farmName",required = true) String farmName){
        // 验证token
        Result result = tokenUtil.verifyToken(accessToken);
        if(!result.isSuccess()){
            return result;
        }
        return new Result(ResultCode.SUCCESS,erpDataService.getMateQuantity(startDate,endDate,farmName));
    }

    /**
     * @Method      : getConceptionRate
     * @Description : 受胎率
     * @Params      : []
     * @Return      : java.lang.String
     * 
     * @Author      : ZhuoNing
     * @Date        : 2021/5/15       
     * @Time        : 11:38
     */
    @RequestMapping("/getConceptionRate")
    public Result getConceptionRate(@Param(value="startDate") String startDate,@Param(value="endDate") String endDate,@RequestParam(value = "accessToken",required = true) String accessToken,@RequestParam(value = "farmName",required = true) String farmName){
        // 验证token
        Result result = tokenUtil.verifyToken(accessToken);
        if(!result.isSuccess()){
            return result;
        }
        return new Result(ResultCode.SUCCESS,erpDataService.getConceptionRate(startDate,endDate,farmName));
    }

    /**
     * @Method      : getAllStorage
     * @Description : 总存栏，母猪存栏
     * @Params      : []
     * @Return      : java.lang.String
     * 
     * @Author      : ZhuoNing
     * @Date        : 2021/5/15       
     * @Time        : 11:39
     */
    @RequestMapping("/getAllStorage")
    public Result getAllStorage(@RequestParam(value = "accessToken",required = true) String accessToken,@RequestParam(value = "farmName",required = true) String farmName){
        // 验证token
        Result result = tokenUtil.verifyToken(accessToken);
        if(!result.isSuccess()){
            return result;
        }
        return new Result(ResultCode.SUCCESS,erpDataService.getAllStorage(farmName));
    }

    /**
     * @Method      : getPigletSurvivalRate
     * @Description : 获取仔猪存活率
     * @Params      : [startDate, endDate, accessToken, farmName]
     * @Return      : com.huimv.common.result.Result
     * 
     * @Author      : ZhuoNing
     * @Date        : 2021/6/30       
     * @Time        : 13:27
     */
    @RequestMapping("/getPigletSurvivalRate")
    public Result getPigletSurvivalRate(@Param(value="startDate") String startDate,@Param(value="endDate") String endDate,@RequestParam(value = "accessToken",required = true) String accessToken,@RequestParam(value = "farmID",required = true) String farmID){
        // 验证token
        Result result = tokenUtil.verifyToken(accessToken);
        if(!result.isSuccess()){
            return result;
        }
        return new Result(ResultCode.SUCCESS,erpDataService.getPigletSurvivalRate(startDate,endDate,farmID));
    }

    @RequestMapping("/getTStockHistory")
    public Result getTStockHistory(@RequestParam(value = "farmID",required = true) String farmID){
        return new Result(ResultCode.SUCCESS,erpDataService.getTStockHistory(farmID));
    }

    /**
     * @Method      : getCostWithManyFarm
     * @Description : 读取多个牧场的成本数据
     * @Params      : [month, accessToken]
     * @Return      : com.huimv.common.result.Result
     * 
     * @Author      : ZhuoNing
     * @Date        : 2021/11/13       
     * @Time        : 17:56
     */
    @RequestMapping(value = "/getCostWithManyFarm",method = RequestMethod.GET)
//    public Result getCostWithManyFarm(@RequestParam(value = "month") String month,@RequestParam(value = "accessToken",required = true) String accessToken){
    public Result getCostWithManyFarm(@RequestParam(value = "year") String year,@RequestParam(value = "month") String month,@RequestParam(value = "accessToken",required = true) String accessToken){
        log.info("输入参数-->");
        log.info("month="+month);
        if(month.trim().length()==1){
            month="0"+month;
        }
        String yearMonth = year+"年"+month+"月份";
        // 验证token
        Result result = tokenUtil.verifyToken(accessToken);
        if(!result.isSuccess()){
            return result;
        }
        return erpDataService.getCostWithManyFarm(yearMonth);
    }

    /**
     * @Method      : getManyFarmStock
     * @Description : 获取多个牧场的存栏
     * @Params      : [accessToken]
     * @Return      : com.huimv.common.result.Result
     *
     * @Author      : ZhuoNing
     * @Date        : 2021/11/13
     * @Time        : 18:49
     */
    @RequestMapping(value = "/getManyFarmStock",method = RequestMethod.GET)
    public  Result getManyFarmStock(@RequestParam(value = "accessToken",required = true) String accessToken){
        // 验证token
        Result result = tokenUtil.verifyToken(accessToken);
        if(!result.isSuccess()){
            return result;
        }
        //
        return erpDataService.getManyFarmStock();
    }

    /**
     * @Method      : getManyFarmProduce
     * @Description : 获取多个牧场的生产数据
     * @Params      : [accessToken]
     * @Return      : com.huimv.common.result.Result
     * 
     * @Author      : ZhuoNing
     * @Date        : 2021/11/13       
     * @Time        : 18:53
     */
    @RequestMapping(value = "/getManyFarmProduce",method = RequestMethod.GET)
    public Result getManyFarmProduce(
            @RequestParam(value = "startDate",required = true) String startDate,
            @RequestParam(value = "endDate",required = true) String endDate,
            @RequestParam(value = "accessToken",required = true) String accessToken){
        // 验证token
        Result result = tokenUtil.verifyToken(accessToken);
        if(!result.isSuccess()){
            return result;
        }
        //
        return erpDataService.getManyFarmProduce(startDate,endDate);
    }

    /**
     * @Method      : getWarning
     * @Description : 获取预警信息
     * @Params      : []
     * @Return      : com.huimv.common.result.Result
     *
     * @Author      : ZhuoNing
     * @Date        : 2021/11/19
     * @Time        : 15:41
     */
    @RequestMapping(value = "/getWarningMessage",method = RequestMethod.GET)
    public Result getWarningMessage(@RequestParam(value = "accessToken",required = true) String accessToken) throws IOException {
        // 验证token
        Result result = tokenUtil.verifyToken(accessToken);
        if(!result.isSuccess()){
            return result;
        }
        //
        return erpDataService.getWarningMessage();
    }

    /**
     * @Method      : getWorkPlan
     * @Description : 工作计划
     * @Params      : [startDate, endDate, accessToken]
     * @Return      : com.huimv.common.result.Result
     * 
     * @Author      : ZhuoNing
     * @Date        : 2021/11/22       
     * @Time        : 17:47
     */
    @RequestMapping(value = "/getWorkPlan",method = RequestMethod.GET)
    public Result getWorkPlan( @RequestParam(value = "startDate",required = true) String startDate,
                               @RequestParam(value = "endDate",required = true) String endDate,
                               @RequestParam(value = "accessToken",required = true) String accessToken) throws IOException {
        // 验证token
        Result result = tokenUtil.verifyToken(accessToken);
        if(!result.isSuccess()){
            return result;
        }
        //
        return erpDataService.getWorkPlan(startDate,endDate);
    }

    /**
     * @Method      : getPrepareStatusQuantity
     * @Description : 获取各种准备状态数量
     * @Params      : [accessToken]
     * @Return      : com.huimv.common.result.Result
     * 
     * @Author      : ZhuoNing
     * @Date        : 2021/11/22       
     * @Time        : 17:58
     */
    @RequestMapping(value = "/getPrepareStatusQuantity",method = RequestMethod.GET)
    public Result getPrepareStatusQuantity(@RequestParam(value = "accessToken",required = true) String accessToken){
        // 验证token
        Result result = tokenUtil.verifyToken(accessToken);
        if(!result.isSuccess()){
            return result;
        }
        //
        return erpDataService.getPrepareStatusQuantity();
    }

    /**
     * @Method      : getPayable
     * @Description : 读取应付数据
     * @Params      : []
     * @Return      : com.huimv.common.result.Result
     * 
     * @Author      : ZhuoNing
     * @Date        : 2021/11/22       
     * @Time        : 18:05
     */
    @RequestMapping(value = "/getPayable",method = RequestMethod.GET)
    public Result getPayable(@RequestParam(value = "accessToken",required = true) String accessToken){
        //验证token
        Result result = tokenUtil.verifyToken(accessToken);
        if(!result.isSuccess()){
            return result;
        }
        //
        return erpDataService.getPayable();
    }

    /**
     * @Method      : getSales
     * @Description : 读取销售数据
     * @Params      : []
     * @Return      : com.huimv.common.result.Result
     *
     * @Author      : ZhuoNing
     * @Date        : 2021/11/22
     * @Time        : 19:11
     */
    @RequestMapping(value = "/getSales",method = RequestMethod.GET)
    public Result getSales(@RequestParam(value = "accessToken",required = true) String accessToken){
        //验证token
        Result result = tokenUtil.verifyToken(accessToken);
        if(!result.isSuccess()){
            return result;
        }
        //
        return erpDataService.getSales();
    }

}
