package com.huimv.production.datasource.service.impl;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.huimv.common.date.DateUtil;
import com.huimv.common.result.Result;
import com.huimv.common.result.ResultCode;
import com.huimv.production.datasource.dao.repo.TDeliveryRepo;
import com.huimv.production.datasource.service.IErpDataService;
import com.huimv.production.datasource.utils.DateUtils;
import com.huimv.production.datasource.utils.MathUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

/**
 * @Project : huimv.shiwan
 * @Package : com.huimv.biosafety.uface.controller
 * @Description : TODO
 * @Version : 1.0
 * @Author : ZhuoNing
 * @Create : 2020-12-25
 **/
@Service
@Slf4j
public class ErpDataServiceImpl implements IErpDataService {
    @Value("${apiService.data.getStorage.isDemo}")
    private String isDemo;
    @Autowired
    private TDeliveryRepo tDeliveryRepo;
    @Autowired
    private MathUtil mathUtil;

    /**
     * @Method : getPsy
     * @Description : Psy
     * @Params : []
     * @Return : java.lang.String
     * @Author : ZhuoNing
     * @Date : 2021/5/15
     * @Time : 11:40
     */
    @Override
    public String getPsy(String farmID, String startDate, String endDate) {
        log.info(" 开始日期（PSY） startDate:" + startDate);
        log.info(" 结束日期（PSY） endDate:" + endDate);
        List<Object[]> psyFieldList = tDeliveryRepo.getPsy(startDate, endDate, farmID);
        log.info(" 返情率查询数量:" + psyFieldList.size());
        String psy = "";
        for (Object[] goodsObj : psyFieldList) {
            psy = goodsObj[0].toString();
        }
        return psy;
    }

    /**
     * @Method : getReEstrusRate
     * @Description : 返情率
     * @Params : []
     * @Return : java.lang.String
     * @Author : ZhuoNing
     * @Date : 2021/5/15
     * @Time : 11:41
     */
    @Override
    public String getReEstrusRate(String startDate, String endDate, String farmName) {
        log.info(" 开始日期（返情率） startDate:" + startDate);
        log.info(" 结束日期（返情率） endDate:" + endDate);
        log.info(" 牧场名称（返情率） farmName:" + farmName);
        List<Object[]> reEstrusRateFieldList = tDeliveryRepo.getReEstrusRate(startDate, endDate, farmName);
        log.info(" 返情率查询数量:" + reEstrusRateFieldList.size());
        JSONArray resultJa = new JSONArray();
        for (Object[] fieldObj : reEstrusRateFieldList) {
            String farmVal = fieldObj[0].toString();
//            String varietyVal = fieldObj[1].toString();
            String reEstrusRateVal = fieldObj[1].toString();
            JSONObject dataJo = new JSONObject();
            dataJo.put("farm", farmVal);
//            dataJo.put("variety",varietyVal);
            dataJo.put("reestrus_rate", reEstrusRateVal);
            resultJa.add(dataJo);
        }

        return resultJa.toJSONString();
    }

    /**
     * @Method : getParturitionRate
     * @Description : 分娩率
     * @Params : []
     * @Return : java.lang.String
     * @Author : ZhuoNing
     * @Date : 2021/5/15
     * @Time : 11:41
     */
    @Override
    public String getParturitionRate(String startDate, String endDate, String farmName) {
        log.info(" 开始日期（分娩率） startDate:" + startDate);
        log.info(" 结束日期（分娩率） endDate:" + endDate);
        log.info(" 牧场名称（分娩率） farmName:" + farmName);
        List<Object[]> fieldList = tDeliveryRepo.getParturitionRate(startDate, endDate, farmName);
        log.info(" 分娩率查询数量:" + fieldList.size());
        JSONArray resultJa = new JSONArray();
        for (Object[] fieldObj : fieldList) {
            String farmVal = fieldObj[0].toString();
//            String varietyVal = fieldObj[1].toString();
            String reEstrusRateVal = fieldObj[1].toString();
            JSONObject dataJo = new JSONObject();
            dataJo.put("farm", farmVal);
            dataJo.put("parturition_rate", reEstrusRateVal);
            resultJa.add(dataJo);
        }

        return resultJa.toJSONString();
    }

    /**
     * @Method : getStorage
     * @Description : 各品种及各自存栏
     * @Params : []
     * @Return : java.lang.String
     * @Author : ZhuoNing
     * @Date : 2021/5/15
     * @Time : 11:42
     */
    @Override
    public String getStorage(String farmName) {
        log.info(" 牧场名称（各品种及各自存栏） farmName:" + farmName);
        List<Object[]> fieldList = tDeliveryRepo.getStorage(farmName);
        log.info(" 各种存栏查询数量:" + fieldList.size());
        JSONArray resultJa = new JSONArray();
        for (Object[] fieldObj : fieldList) {
            //
            String farm = "";
            if (fieldObj[0] == null) {
                farm = "";
            } else {
                farm = fieldObj[0].toString();
            }
            //
            String name = "";
            if (fieldObj[1] == null) {
                name = "";
            } else {
                name = fieldObj[1].toString();
            }
            //
            String quantity = "";
            if (quantity == null) {
                quantity = "";
            } else {
                quantity = fieldObj[2].toString();
            }
            JSONObject dataJo = new JSONObject();
            dataJo.put("farm", farm);
            dataJo.put("name", name);
            dataJo.put("quantity", quantity);
            resultJa.add(dataJo);
        }
        if (isDemo.equalsIgnoreCase("0")) {
            // 返回真实结果
            return resultJa.toJSONString();
        } else {
            //模拟结果
            JSONArray demoJa = new JSONArray();
            JSONObject demoJo1 = new JSONObject();
            demoJa.add(demoJo1);
            demoJo1.put("farm", "海盐曙光");
            demoJo1.put("name", "杜巴嘉");
            demoJo1.put("quantity", "2873");

            JSONObject demoJo2 = new JSONObject();
            demoJa.add(demoJo2);
            demoJo2.put("farm", "海盐曙光");
            demoJo2.put("name", "杜杜巴嘉");
            demoJo2.put("quantity", "545");

            JSONObject demoJo3 = new JSONObject();
            demoJa.add(demoJo3);
            demoJo3.put("farm", "海盐曙光");
            demoJo3.put("name", "三元");
            demoJo3.put("quantity", "555");

            JSONObject demoJo4 = new JSONObject();
            demoJa.add(demoJo4);
            demoJo4.put("farm", "海盐曙光");
            demoJo4.put("name", "嘉兴黑猪");
            demoJo4.put("quantity", "239");

            return demoJa.toJSONString();
        }
    }

    /**
     * @Method : getPigletInfo
     * @Description : 均产仔数，仔猪存活率
     * @Params : []
     * @Return : java.lang.String
     * @Author : ZhuoNing
     * @Date : 2021/5/15
     * @Time : 11:43
     */
    @Override
    public String getPigletInfo(String startDate, String endDate, String farmName) {
        log.info(" 开始日期（均产仔数，仔猪存活率） startDate:" + startDate);
        log.info(" 结束日期（均产仔数，仔猪存活率） endDate:" + endDate);
        log.info(" 牧场名称（均产仔数，仔猪存活率） farmName:" + farmName);
        List<Object[]> fieldList = tDeliveryRepo.getPigletInfo(startDate, endDate, farmName);
        log.info(" 均产仔数，仔猪存活率查询数量:" + fieldList.size());
        JSONArray resultJa = new JSONArray();
        for (Object[] fieldObj : fieldList) {
            String farm = fieldObj[0].toString();
            String birth_number = fieldObj[1].toString();
            String total = fieldObj[2].toString();
            String dead_quantity = fieldObj[3].toString();
            JSONObject dataJo = new JSONObject();
            dataJo.put("farm", farm);
            dataJo.put("birth_number", birth_number);
            dataJo.put("total", total);
            dataJo.put("dead_quantity", dead_quantity);
            resultJa.add(dataJo);
        }

        return resultJa.toJSONString();
    }

    /**
     * @Method : getMateQuantity
     * @Description : 配种数量
     * @Params : []
     * @Return : java.lang.String
     * @Author : ZhuoNing
     * @Date : 2021/5/15
     * @Time : 11:44
     */
    @Override
    public String getMateQuantity(String startDate, String endDate, String farmName) {
        log.info(" 开始日期（配种数量） startDate:" + startDate);
        log.info(" 结束日期（配种数量） endDate:" + endDate);
        log.info(" 牧场名称（配种数量） farmName:" + farmName);
        List<Object[]> fieldList = tDeliveryRepo.getMateQuantity(startDate, endDate, farmName);
        log.info(" 配种查询数量:" + fieldList.size());
        JSONArray resultJa = new JSONArray();
        for (Object[] fieldObj : fieldList) {
            String farm = fieldObj[0].toString();
//            String variety = fieldObj[1].toString();
            String mate_quantity = fieldObj[1].toString();
            JSONObject dataJo = new JSONObject();
            dataJo.put("farm", farm);
//            dataJo.put("variety",variety);
            dataJo.put("mate_quantity", mate_quantity);
            resultJa.add(dataJo);
        }
        return resultJa.toJSONString();
    }

    /**
     * @Method : getConceptionRate
     * @Description : 受胎率
     * @Params : []
     * @Return : java.lang.String
     * @Author : ZhuoNing
     * @Date : 2021/5/15
     * @Time : 11:45
     */
    @Override
    public String getConceptionRate(String startDate, String endDate, String farmName) {
        log.info(" 开始日期（受胎率） startDate:" + startDate);
        log.info(" 结束日期（受胎率） endDate:" + endDate);
        log.info(" 牧场名称（受胎率） farmName:" + farmName);
        List<Object[]> fieldList = tDeliveryRepo.getConceptionRate(startDate, endDate, farmName);
        log.info(" 受胎率查询数量:" + fieldList.size());
        JSONArray resultJa = new JSONArray();
        for (Object[] fieldObj : fieldList) {
            String farm = fieldObj[0].toString();
            String conception_rate = fieldObj[1].toString();
            JSONObject dataJo = new JSONObject();
            dataJo.put("farm", farm);
            dataJo.put("conception_rate", conception_rate);
            resultJa.add(dataJo);
        }
        return resultJa.toJSONString();
    }

    /**
     * @Method : getAllStorage
     * @Description : 总存栏，母猪存栏
     * @Params : []
     * @Return : java.lang.String
     * @Author : ZhuoNing
     * @Date : 2021/5/15
     * @Time : 11:45
     */
    @Override
    public String getAllStorage(String farmName) {
        log.info(" 牧场名称（总存栏，母猪存栏） farmName:" + farmName);
        List<Object[]> fieldList = tDeliveryRepo.getAllStorage(farmName);
        log.info(" 总存栏，母猪存栏查询数量:" + fieldList.size());
        JSONArray resultJa = new JSONArray();
        for (Object[] fieldObj : fieldList) {
            String farm = fieldObj[0].toString();
            String sow_quantity = fieldObj[1].toString();
            String total = fieldObj[2].toString();
            JSONObject dataJo = new JSONObject();
            dataJo.put("farm", farm);
            dataJo.put("sow_quantity", sow_quantity);
            dataJo.put("total", total);
            resultJa.add(dataJo);
        }
        return resultJa.toJSONString();
    }

    /**
     * @Method : getPigletSurvivalRate
     * @Description : 仔猪存活率
     * @Params : [startDate, endDate, farmName]
     * @Return : java.lang.Object
     * @Author : ZhuoNing
     * @Date : 2021/6/30
     * @Time : 13:28
     */
    @Override
    public Object getPigletSurvivalRate(String startDate, String endDate, String farmID) {
        log.info(" 开始日期（仔猪存活率） startDate:" + startDate);
        log.info(" 结束日期（仔猪存活率） endDate:" + endDate);
        log.info(" 牧场名称（仔猪存活率） farmID:" + farmID);
//        List<Object[]> fieldList = tDeliveryRepo.getPigletSurvivalRate(startDate, endDate, farmID);
        List<Object[]> fieldList = tDeliveryRepo.getPigletSurvivalRate2(startDate, endDate, farmID);
        log.info(" 仔猪存活率查询数量:" + fieldList.size());
        JSONArray resultJa = new JSONArray();
        for (Object[] fieldObj : fieldList) {
            String pigletSurvivalRate = fieldObj[0].toString();
            String farm = fieldObj[1].toString();
            JSONObject dataJo = new JSONObject();
            dataJo.put("farm", farm);
            dataJo.put("piglet_survival_rate", pigletSurvivalRate);
            resultJa.add(dataJo);
        }
        System.out.println("resultJa>>" + resultJa);
        return resultJa.toJSONString();
    }

    @Override
    public Object getTStockHistory(String farmID) {
        List<Object[]> fieldList = tDeliveryRepo.getTStockHistory(farmID);
        log.info(" SQL:" + fieldList.size());
        String countFid = "";
        for (Object[] fieldObj : fieldList) {
            countFid = fieldObj[0].toString();
            System.out.println("countFid:"+countFid);
        }
        return countFid;
    }

    /**
     * @Method      : getCostWithManyFarm
     * @Description : 获取多牧场成本数据
     * @Params      : [month]
     * @Return      : com.huimv.common.result.Result
     * 
     * @Author      : ZhuoNing
     * @Date        : 2021/11/13       
     * @Time        : 18:39
     */
    @Override
    public Result getCostWithManyFarm(String yearMonth) {
        System.out.println("yearMonth="+yearMonth);
        //
        List<Object[]> costList = tDeliveryRepo.getCostWithManyFarm(yearMonth);
        System.out.println("costList.size="+costList.size());
        JSONArray costJa = new JSONArray();
        for(int a=0;a<costList.size();a++){
            Object[] costObj = (Object[]) costList.get(a);
//            for(int b=0;b<costObj.length;b++){
//                System.out.println(b+"="+costObj[b]);
//            }
//            System.out.println();
            JSONObject dataJo = new JSONObject();
            costJa.add(dataJo);
            //牧场名称
            dataJo.put("mcmc", costObj[0]);
            //基础猪群
            dataJo.put("jczq", costObj[1]);
            //保育猪群
            dataJo.put("byzq", costObj[2]);
            //育肥
            dataJo.put("yf", costObj[3]);
            //后备
            dataJo.put("hb", costObj[4]);
            //共同费用
            dataJo.put("gtfy", costObj[5]);
            //合计
            dataJo.put("hj", costObj[6]);
            //项目名称
            dataJo.put("xmmc", costObj[7]);
        }
        return new Result(ResultCode.SUCCESS,costJa);
    }
    /**
     * @Method      : getManyFarmStock
     * @Description : 获取多个牧场的存栏数据
     * @Params      : []
     * @Return      : com.huimv.common.result.Result
     * 
     * @Author      : ZhuoNing
     * @Date        : 2021/11/13       
     * @Time        : 18:50
     */
    @Override
    public Result getManyFarmStock() {
        //
        List<Object[]> stockList = tDeliveryRepo.getManyFarmStock();
        JSONArray stockJa = new JSONArray();
        for(int a=0;a<stockList.size();a++){
            Object[] stockObj = (Object[]) stockList.get(a);
            JSONObject dataJo = new JSONObject();
            stockJa.add(dataJo);
            //牧场名称
            dataJo.put("mcmc", stockObj[0]);
            //母猪
            dataJo.put("mz", stockObj[1]);
            //公猪
            dataJo.put("gz", stockObj[2]);
            //仔猪
            dataJo.put("zz", stockObj[3]);
            //保育
            dataJo.put("by", stockObj[4]);
            //育肥
            dataJo.put("yf", stockObj[5]);
            //后备
            dataJo.put("hb", stockObj[6]);
            //妊娠
            dataJo.put("rs", stockObj[7]);
            //哺乳
            dataJo.put("br", stockObj[8]);
            //空怀
            dataJo.put("kh", stockObj[9]);
        }
        return new Result(ResultCode.SUCCESS,stockJa);
    }

    @Autowired
    private DateUtils dateUtils;

    /**
     * @Method      : getManyFarmProduce
     * @Description : 获取多个牧场生产数据
     * @Params      : []
     * @Return      : com.huimv.common.result.Result
     * 
     * @Author      : ZhuoNing
     * @Date        : 2021/11/13       
     * @Time        : 18:50
     */
    @Override
    public Result getManyFarmProduce(String startDateText,String endDateText) {
        Date startDate = dateUtils.parseDate(startDateText);
        Date endDate = dateUtils.parseDate(endDateText);
        //
        List<Object[]> stockList = tDeliveryRepo.getManyFarmProduce(startDate,endDate);
        JSONArray produceJa = new JSONArray();
        for(int a=0;a<stockList.size();a++){
            Object[] stockObj = (Object[]) stockList.get(a);
            JSONObject dataJo = new JSONObject();
            produceJa.add(dataJo);
            //牧场名称
            dataJo.put("mcmc", stockObj[0]);
            //产房成活率
            dataJo.put("cfchl", stockObj[1]);
            //保育成活率
            dataJo.put("bychl", stockObj[2]);
            //肥猪成活率
            dataJo.put("fzchl", stockObj[3]);
            //平均窝产仔猪
            dataJo.put("pjwczz", stockObj[4]);
            //平均窝产活仔数
            dataJo.put("pjwchzs", stockObj[5]);
            //平均窝产正常仔数
            dataJo.put("pjwczczs", stockObj[6]);
            //窝断奶仔猪数
            dataJo.put("wdnzzs", stockObj[7]);
            //平均断奶窝重
            dataJo.put("pjdnwz", stockObj[8]);
            //7日断配率
            dataJo.put("7rdpl", stockObj[9]);
            //年产窝数
            dataJo.put("ncws", stockObj[10]);
        }
        return new Result(ResultCode.SUCCESS,produceJa);
    }

    @Override
    public Result getWarningMessage() {
        //
        List<Object[]> stockList = tDeliveryRepo.getWarningMessage();
        JSONArray produceJa = new JSONArray();
        for(int a=0;a<stockList.size();a++){
            Object[] stockObj = (Object[]) stockList.get(a);
            JSONObject dataJo = new JSONObject();
            produceJa.add(dataJo);
            //消息内容
            dataJo.put("xxnr", stockObj[0]);
            //提示日期
            dataJo.put("tsrq", stockObj[1]);
        }
        return new Result(ResultCode.SUCCESS,produceJa);
    }

    @Override
    public Result getWorkPlan(String startDateText,String endDateText) {
        Date startDate = dateUtils.parseDate(startDateText);
        Date endDate = dateUtils.parseDate(endDateText);
        //
        List<Object[]> workPlanList = tDeliveryRepo.getWorkPlan1(startDate,endDate);
        System.out.println("workPlanList.size="+workPlanList.size());
        JSONArray produceJa = new JSONArray();
        for(int a=0;a<workPlanList.size();a++){
            Object[] planObj = (Object[]) workPlanList.get(a);
            JSONObject dataJo = new JSONObject();
            produceJa.add(dataJo);
            //牧场名称
            dataJo.put("mcmc", planObj[0]);
            //计划名称
            dataJo.put("jhmc", planObj[1]);
            //计划条数
            dataJo.put("jhts", planObj[2]);
            //猪只数量
            dataJo.put("zzsl", planObj[3]);
        }
        return new Result(ResultCode.SUCCESS,produceJa);
    }

    @Override
    public Result getPrepareStatusQuantity() {
        //
        List<Object[]> prepareStatusList = tDeliveryRepo.getPrepareStatusQuantity();
        JSONArray produceJa = new JSONArray();
        for(int a=0;a<prepareStatusList.size();a++){
            Object[] planObj = (Object[]) prepareStatusList.get(a);
            JSONObject dataJo = new JSONObject();
            produceJa.add(dataJo);
            //牧场名称
            dataJo.put("mcmc", planObj[0]);
            //待分娩
            dataJo.put("dfm", planObj[1]);
            //待断奶
            dataJo.put("ddn", planObj[2]);
            //待配种
            dataJo.put("dpz", planObj[3]);
        }
        return new Result(ResultCode.SUCCESS,produceJa);
    }

    @Override
    public Result getPayable() {
        //
        List<Object[]> payableList = tDeliveryRepo.getPayable();
        JSONArray produceJa = new JSONArray();
        for(int a=0;a<payableList.size();a++){
            Object[] planObj = (Object[]) payableList.get(a);
            JSONObject dataJo = new JSONObject();
            produceJa.add(dataJo);
            //排名
            dataJo.put("rank", planObj[0]);
            //牧场名称
            dataJo.put("mcmc", planObj[1]);
            //金额
            dataJo.put("je", planObj[2]);
            //应付单位
            dataJo.put("supplier", planObj[3]);
        }
        return new Result(ResultCode.SUCCESS,produceJa);
    }

    @Override
    public Result getSales() {
        //
        List<Object[]> salesList = tDeliveryRepo.getSales();
        System.out.println("salesList.size="+salesList.size());
        JSONArray produceJa = new JSONArray();
        for(int a=0;a<salesList.size();a++){
            Object[] salesObj = (Object[]) salesList.get(a);
            JSONObject dataJo = new JSONObject();
            produceJa.add(dataJo);
//            System.out.println("planObj[0].toString()="+salesObj[0]);
//            System.out.println("planObj[1].toString()="+salesObj[1]);
//            System.out.println("planObj[2].toString()="+salesObj[2]);
//            System.out.println("planObj[3].toString()="+salesObj[3]);
//            System.out.println("planObj[4].toString()="+salesObj[4]);
//            System.out.println("planObj[5].toString()="+salesObj[5]);
//            System.out.println("planObj[6].toString()="+salesObj[6]);
//            System.out.println("planObj[7].toString()="+salesObj[7]);
//            System.out.println("planObj[8].toString()="+salesObj[8]);
            //牧场名称
            dataJo.put("farm_name", salesObj[0]);
            //今日数量
//            float f1 = 0;
//            if(salesObj[0] != null){
//                f1 = Float.parseFloat(salesObj[0].toString().replace(",",""));
//            }else{
//                System.out.println("==null");
//            }
            dataJo.put("today_quantity", salesObj[1]);
            //今日重量
//            float f2 = 0;
//            if(salesObj[1] != null){
//                f2 = Float.parseFloat(salesObj[1].toString().replace(",",""));
//            }
            dataJo.put("today_weight", salesObj[2]);
            //今日金额
//            float f3 = 0;
//            if(salesObj[2] != null){
//                f3 = Float.parseFloat(salesObj[2].toString().replace(",",""));
//            }
            dataJo.put("today_money",  salesObj[3]);
            //本周数量
//            float f4 = 0;
//            if(salesObj[3] != null){
//                f4 = Float.parseFloat(salesObj[3].toString().replace(",",""));
//            }
            dataJo.put("week_quantity", salesObj[4]);
            //本周重量
//            float f5 = 0;
//            if(salesObj[4] != null){
//                f5 = Float.parseFloat(salesObj[4].toString().replace(",",""));
//            }
            dataJo.put("week_weight", salesObj[5]);
            //本周金额
//            float f6 = 0;
//            if(salesObj[5] != null){
//                f6 = Float.parseFloat(salesObj[5].toString().replace(",",""));
//            }
            dataJo.put("week_money", salesObj[6]);
            //本月数量
//            float f7 = 0;
//            if(salesObj[6] != null){
//                f7 = Float.parseFloat(salesObj[6].toString().replace(",",""));
//            }
            dataJo.put("month_quantity", salesObj[7]);
            //本月重量
//            float f8 = 0;
//            if(salesObj[7] != null){
//                f8 = Float.parseFloat(salesObj[7].toString().replace(",",""));
//            }
            dataJo.put("month_weight", salesObj[8]);
            //本月金额
//            float f9 = 0;
//            if(salesObj[8] != null){
//                f9 = Float.parseFloat(salesObj[8].toString().replace(",",""));
//            }
            dataJo.put("month_money",  salesObj[9]);
        }
        return new Result(ResultCode.SUCCESS,produceJa);
    }

}
